==> babel-1.1.3.tgz: package/src/babel.config.js <==
/*

Copyright (C) 2016,2017 wallzero 2016,2017

This program is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software Foundation,
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this
program. If not, see <http://www.gnu.org/licenses/>.

*/

/*
  eslint-disable
  filenames/match-regex,
  import/unambiguous,
  import/no-commonjs,
  complexity,
  no-nested-ternary
*/

const {
  angular,
  context,
  cssModules,
  flow,
  HASH_LIMIT,
  library,
  production,
  react,
  shortName,
  typescript
} = require('@digest/scripts');

module.exports = function (api) {
  if (api) {
    api.cache(true);
  }

  return {
    plugins: [
      // Stage 0
      ['@babel/plugin-proposal-function-bind'],

      // Stage 1
      ['@babel/plugin-proposal-export-default-from'],
      ['@babel/plugin-proposal-logical-assignment-operators'],
      ['@babel/plugin-proposal-optional-chaining', {loose: false}],
      ['@babel/plugin-proposal-pipeline-operator', {proposal: 'minimal'}],
      ['@babel/plugin-proposal-nullish-coalescing-operator', {loose: false}],
      ['@babel/plugin-proposal-do-expressions'],

      // Stage 2
      ['@babel/plugin-proposal-decorators', {legacy: true}],
      ['@babel/plugin-proposal-function-sent'],
      ['@babel/plugin-proposal-export-namespace-from'],
      ['@babel/plugin-proposal-numeric-separator'],
      ['@babel/plugin-proposal-throw-expressions'],

      // Stage 3
      ['@babel/plugin-syntax-dynamic-import'],
      ['@babel/plugin-syntax-import-meta'],
      ['@babel/plugin-proposal-class-properties', {loose: false}],
      ['@babel/plugin-proposal-object-rest-spread'],
      ['@babel/plugin-proposal-json-strings']
    ].concat(
      [['babel-plugin-dynamic-import-node-babel-7']],
      production ?
        [['babel-plugin-transform-node-env-inline']] :
        [],
      angular ?
        [['babel-plugin-angular2-annotations']] :
        [],
      [
        ['@babel/plugin-transform-destructuring'],
        ['@babel/plugin-transform-runtime', {
          helpers: false,
          regenerator: true
        }],
        ['@babel/plugin-transform-regenerator', {
          async: false
        }],
        ['@babel/plugin-transform-classes']
      ],
      cssModules && react ?
        [['babel-plugin-react-css-modules', {
          context,
          generateScopedName: library ?
            shortName + '-[local]' :
            '[local]-[hash:' + HASH_LIMIT + ']'
        }]] :
        [],
      production && react && !library ?
        [
          ['babel-plugin-transform-react-remove-prop-types', {
            removeImport: true
          }],

          // Breaks react-hot-loader, only use in production and NOT for libraries
          ['@babel/plugin-transform-react-inline-elements']
        ] :
        [],
      production && react ?
        [[
          '@babel/plugin-transform-react-constant-elements',
          {allowMutablePropsOnTags: ['FormattedMessage']}
        ]] :
        [],
      !production && react ?
        [['react-hot-loader/babel']] :
        []
    ),
    presets: [].concat(
      production ?
        [['babel-preset-minify', {
          removeConsole: true,
          removeDebugger: true,
          removeUndefined: false,
          simplify: true
        }]] :
        [],
      [['@babel/preset-env', {
        debug: false,
        forceAllTransforms: true,

        // decoratorsLegacy: true,
        modules: false,
        targets: {
          browsers: ['last 2 versions', 'safari 7', 'ie 9'],
          chrome: '52',
          node: '6.10'
        },
        useBuiltIns: 'entry'
      }]],
      react ?
        [['@babel/preset-react', {
          development: !production,
          useBuiltIns: true
        }]] :
        [],
      typescript ?
        [['@babel/preset-typescript', {
          useBuiltIns: true
        }]] :
        flow ?
          [['@babel/preset-flow', {
            useBuiltIns: true
          }]] :
          []
    )
  };
};

==> babel-1.3.0.tgz: package/src/babel.config.js <==
/*

Copyright (C) 2016,2017 wallzero 2016,2017

This program is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software Foundation,
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this
program. If not, see <http://www.gnu.org/licenses/>.

*/

/*
  eslint-disable
  filenames/match-regex,
  import/unambiguous,
  import/no-commonjs,
  complexity,
  no-nested-ternary
*/

const config = require('@digest/scripts').default;

module.exports = function (api) {
  if (api) {
    api.cache(true);
  }

  return {
    plugins: [
      // Stage 0
      ['@babel/plugin-proposal-function-bind'],

      // Stage 1
      ['@babel/plugin-proposal-export-default-from'],
      ['@babel/plugin-proposal-logical-assignment-operators'],
      ['@babel/plugin-proposal-optional-chaining', {loose: false}],
      ['@babel/plugin-proposal-pipeline-operator', {proposal: 'minimal'}],
      ['@babel/plugin-proposal-nullish-coalescing-operator', {loose: false}],
      ['@babel/plugin-proposal-do-expressions'],

      // Stage 2
      ['@babel/plugin-proposal-decorators', {legacy: true}],
      ['@babel/plugin-proposal-function-sent'],
      ['@babel/plugin-proposal-export-namespace-from'],
      ['@babel/plugin-proposal-numeric-separator'],
      ['@babel/plugin-proposal-throw-expressions'],

      // Stage 3
      ['@babel/plugin-syntax-dynamic-import'],
      ['@babel/plugin-syntax-import-meta'],
      ['@babel/plugin-proposal-class-properties', {loose: false}],
      ['@babel/plugin-proposal-object-rest-spread'],
      ['@babel/plugin-proposal-json-strings']
    ].concat(
      [['babel-plugin-dynamic-import-node-babel-7']],
      config.production ?
        [['babel-plugin-transform-node-env-inline']] :
        [],
      config.angular ?
        [['babel-plugin-angular2-annotations']] :
        [],
      [
        ['@babel/plugin-transform-destructuring'],
        ['@babel/plugin-transform-runtime', {
          helpers: false,
          regenerator: true
        }],
        ['@babel/plugin-transform-regenerator', {
          async: false
        }],
        ['@babel/plugin-transform-classes']
      ],
      config.cssModules && config.react ?
        [['babel-plugin-react-css-modules', {
          context: config.context,
          generateScopedName: config.library ?
            config.shortName + '-[local]' :
            '[local]-[hash:' + config.HASH_LIMIT + ']'
        }]] :
        [],
      config.production && config.react && !config.library ?
        [
          ['babel-plugin-transform-react-remove-prop-types', {
            removeImport: true
          }],

          // Breaks react-hot-loader, only use in production and NOT for libraries
          ['@babel/plugin-transform-react-inline-elements']
        ] :
        [],
      config.production && config.react ?
        [[
          '@babel/plugin-transform-react-constant-elements',
          {allowMutablePropsOnTags: ['FormattedMessage']}
        ]] :
        [],
      !config.production && config.react ?
        [['react-hot-loader/babel']] :
        []
    ),
    presets: [].concat(
      config.production ?
        [['babel-preset-minify', {
          removeConsole: true,
          removeDebugger: true,
          removeUndefined: false,
          simplify: true
        }]] :
        [],
      [['@babel/preset-env', {
        debug: false,
        forceAllTransforms: true,

        // decoratorsLegacy: true,
        modules: false,
        targets: {
          browsers: ['last 2 versions', 'safari 7', 'ie 9'],
          chrome: '52',
          node: '6.10'
        },
        useBuiltIns: 'entry'
      }]],
      config.react ?
        [['@babel/preset-react', {
          development: !config.production,
          useBuiltIns: true
        }]] :
        [],
      config.typescript ?
        [['@babel/preset-typescript', {
          useBuiltIns: true
        }]] :
        config.flow ?
          [['@babel/preset-flow', {
            useBuiltIns: true
          }]] :
          []
    )
  };
};
